@@ -33,8 +33,6 @@ DNSTAP_TYPE = { 1: 'AUTH_QUERY', 2: 'AUTH_RESPONSE',
 DNSTAP_FAMILY = {1: 'IP4', 2: 'IP6'}
 DNSTAP_PROTO = {1: 'UDP', 2: 'TCP'}    
 
-DATETIME_FORMAT ='%Y-%m-%d %H:%M:%S.%f'
-
 # command line arguments definition
 parser = argparse.ArgumentParser()
 parser.add_argument("-l", 
@@ -234,7 +232,7 @@ def start_receiver():
     # asynchronous unix socket
     if cfg["input-mode"]["unix-socket"] is not None:
         logging.debug("Listening on %s" % args.u)
-        socket_server = asyncio.start_unix_server(cb_onconnect,
+        socket_server = asyncio.start_unix_server(lambda r, w: cb_onconnect(r, w, cfg),
                                                   path=cfg["input-mode"]["unix-socket"],
                                                   loop=loop)
     # asynchronous tcp socket
@@ -260,4 +258,4 @@ def start_receiver():
     try:
         loop.run_forever()
     except KeyboardInterrupt:
-        pass
\ No newline at end of file
+        pass
